@@ -1,14 +1,14 @@
 import logging
 import warnings
-from itertools import product
 from collections import namedtuple
+from itertools import product
 
 import numpy as np
 import pandas as pd
 
+from pgmpy.extern import tabulate
 from pgmpy.factors.base import BaseFactor
 from pgmpy.utils import StateNameMixin
-from pgmpy.extern import tabulate
 
 State = namedtuple("State", ["var", "state"])
 
@@ -98,6 +98,11 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
         if len(set(variables)) != len(variables):
             raise ValueError("Variable names cannot be same")
 
+        if not isinstance(state_names, dict):
+            raise ValueError(
+                f"state_names must be of type dict. Got {type(state_names)}."
+            )
+
         self.variables = list(variables)
         self.cardinality = np.array(cardinality, dtype=int)
         self.values = values.reshape(self.cardinality)
@@ -113,7 +118,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        list: List of variable names in the scope of the factor.
+        Scope of the factor: list
+            List of variables on which the factor is defined.
 
         Examples
         --------
@@ -135,7 +141,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        dict: Dictionary of the form {variable: variable_cardinality}
+        Cardinality of variables: dict
+            Dictionary of the form {variable: variable_cardinality}
 
         Examples
         --------
@@ -168,7 +175,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        float: The value of states.
+        value of kwargs: float
+            The value of specified states.
 
         Examples
         --------
@@ -250,7 +258,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        list: Returns a list of full assignments of all the variables of the factor.
+        Full assignments: list
+            Returns a list of full assignments of all the variables of the factor.
 
         Examples
         --------
@@ -292,7 +301,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        DiscreteFactor: The identity factor.
+        Identity factor: pgmpy.factors.discrete.DiscreteFactor.
+            Returns a factor with all values set to 1.
 
         Examples
         --------
@@ -331,8 +341,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        DiscreteFactor or None: if inplace=True (default) returns None
-                        if inplace=False returns a new `DiscreteFactor` instance.
+        Marginalized factor: pgmpy.factors.discrete.DiscreteFactor or None
+        If inplace=True (default) returns None else returns a new `DiscreteFactor` instance.
 
         Examples
         --------
@@ -357,11 +367,12 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
         var_indexes = [phi.variables.index(var) for var in variables]
 
         index_to_keep = sorted(set(range(len(self.variables))) - set(var_indexes))
+        n_variables = len(self.variables)
         phi.variables = [phi.variables[index] for index in index_to_keep]
         phi.cardinality = phi.cardinality[index_to_keep]
         phi.del_state_names(variables)
 
-        phi.values = np.sum(phi.values, axis=tuple(var_indexes))
+        phi.values = np.einsum(phi.values, range(n_variables), index_to_keep)
 
         if not inplace:
             return phi
@@ -381,8 +392,9 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        DiscreteFactor or None: if inplace=True (default) returns None
-                        if inplace=False returns a new `DiscreteFactor` instance.
+        Maximized factor: pgmpy.factors.discrete.DiscreteFactor or None
+            If inplace=True (default) returns None else inplace=False returns a
+            new `DiscreteFactor` instance.
 
         Examples
         --------
@@ -434,8 +446,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        DiscreteFactor or None: if inplace=True (default) returns None
-                        if inplace=False returns a new `DiscreteFactor` instance.
+        Normalized factor: pgmpy.factors.discrete.DiscreteFactor or None
+            If inplace=True (default) returns None else returns a new `DiscreteFactor` instance.
 
         Examples
         --------
@@ -487,8 +499,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        DiscreteFactor or None: if inplace=True (default) returns None
-                        if inplace=False returns a new `DiscreteFactor` instance.
+        Reduced factor: pgmpy.factors.discrete.DiscreteFactor or None
+            If inplace=True (default) returns None else returns a new `DiscreteFactor` instance.
 
         Examples
         --------
@@ -558,7 +570,7 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
         Parameters
         ----------
         phi1: float or `DiscreteFactor` instance.
-            If float: the value is added to each value in the factor.
+            If float, the value is added to each value in the factor.
             DiscreteFactor to be added.
 
         inplace: boolean
@@ -567,8 +579,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        DiscreteFactor or None: if inplace=True (default) returns None
-                        if inplace=False returns a new `DiscreteFactor` instance.
+        Summed factor: pgmpy.factors.discrete.DiscreteFactor or None
+            If inplace=True (default) returns None else returns a new `DiscreteFactor` instance.
 
         Examples
         --------
@@ -655,8 +667,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        DiscreteFactor or None: if inplace=True (default) returns None
-                        if inplace=False returns a new `DiscreteFactor` instance.
+        Multiplied factor: pgmpy.factors.discrete.DiscreteFactor or None
+            If inplace=True (default) returns None else returns a new `DiscreteFactor` instance.
 
         Examples
         --------
@@ -686,42 +698,27 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
         if isinstance(phi1, (int, float)):
             phi.values *= phi1
         else:
-            phi1 = phi1.copy()
+            # Compute the new values
+            new_variables = list(set(phi.variables).union(phi1.variables))
+            var_to_int = {var: index for index, var in enumerate(new_variables)}
+            phi.values = np.einsum(
+                phi.values,
+                [var_to_int[var] for var in phi.variables],
+                phi1.values,
+                [var_to_int[var] for var in phi1.variables],
+                range(len(new_variables)),
+            )
 
-            # modifying phi to add new variables
-            extra_vars = set(phi1.variables) - set(phi.variables)
-            if extra_vars:
-                slice_ = [slice(None)] * len(phi.variables)
-                slice_.extend([np.newaxis] * len(extra_vars))
-                phi.values = phi.values[tuple(slice_)]
+            # Compute the new cardinality array
+            phi_card = {var: card for var, card in zip(phi.variables, phi.cardinality)}
+            phi1_card = {
+                var: card for var, card in zip(phi1.variables, phi1.cardinality)
+            }
+            phi_card.update(phi1_card)
+            phi.cardinality = np.array([phi_card[var] for var in new_variables])
 
-                phi.variables.extend(extra_vars)
-
-                new_var_card = phi1.get_cardinality(extra_vars)
-                phi.cardinality = np.append(
-                    phi.cardinality, [new_var_card[var] for var in extra_vars]
-                )
-
-            # modifying phi1 to add new variables
-            extra_vars = set(phi.variables) - set(phi1.variables)
-            if extra_vars:
-                slice_ = [slice(None)] * len(phi1.variables)
-                slice_.extend([np.newaxis] * len(extra_vars))
-                phi1.values = phi1.values[tuple(slice_)]
-
-                phi1.variables.extend(extra_vars)
-                # No need to modify cardinality as we don't need it.
-
-            # rearranging the axes of phi1 to match phi
-            for axis in range(phi.values.ndim):
-                exchange_index = phi1.variables.index(phi.variables[axis])
-                phi1.variables[axis], phi1.variables[exchange_index] = (
-                    phi1.variables[exchange_index],
-                    phi1.variables[axis],
-                )
-                phi1.values = phi1.values.swapaxes(axis, exchange_index)
-
-            phi.values = phi.values * phi1.values
+            # Set the new variables and state names
+            phi.variables = new_variables
             phi.add_state_names(phi1)
 
         if not inplace:
@@ -742,8 +739,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        DiscreteFactor or None: if inplace=True (default) returns None
-                        if inplace=False returns a new `DiscreteFactor` instance.
+        Divided factor: pgmpy.factors.discrete.DiscreteFactor or None
+            If inplace=True (default) returns None else returns a new `DiscreteFactor` instance.
 
         Examples
         --------
@@ -838,7 +835,8 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
 
         Returns
         -------
-        DiscreteFactor: copy of the factor
+        Copy of self: pgmpy.factors.discrete.DiscreteFactor
+            A copy of the original discrete factor.
 
         Examples
         --------
@@ -858,14 +856,14 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
                 [12, 13, 14],
                 [15, 16, 17]]])
         """
-        # not creating a new copy of self.values and self.cardinality
-        # because __init__ methods does that.
-        return DiscreteFactor(
-            self.scope(),
-            self.cardinality,
-            self.values,
-            state_names=self.state_names.copy(),
-        )
+        copy = DiscreteFactor.__new__(self.__class__)
+        copy.variables = [*self.variables]
+        copy.cardinality = np.array(self.cardinality)
+        copy.values = np.array(self.values)
+        copy.state_names = self.state_names.copy()
+        copy.no_to_name = self.no_to_name.copy()
+        copy.name_to_no = self.name_to_no.copy()
+        return copy
 
     def is_valid_cpd(self):
         """
@@ -1019,7 +1017,7 @@ class DiscreteFactor(BaseFactor, StateNameMixin):
             phi.values = phi.values.swapaxes(axis, exchange_index)
         return hash(
             str(sorted_var_hashes)
-            + str(phi.values)
-            + str(phi.cardinality)
+            + str(hash(phi.values.tobytes()))
+            + str(hash(phi.cardinality.tobytes()))
             + str(state_names_hash)
         )
