@@ -85,7 +85,8 @@ class CausalInference(object):
 
         Returns
         -------
-        boolean: True if Z is a valid backdoor adjustment set.
+        Is a valid backdoor adjustment set: bool
+            True if Z is a valid backdoor adjustment set else False
 
         Examples
         --------
@@ -96,8 +97,9 @@ class CausalInference(object):
         >>> inference.is_valid_backdoor_adjustment_set("X", "Y")
         True
         """
-        Z_ = list(Z)
-        observed = [X] + Z_
+        Z_ = _variable_or_iterable_to_set(Z)
+
+        observed = [X] + list(Z_)
         parents_d_sep = []
         for p in self.model.predecessors(X):
             parents_d_sep.append(not self.model.is_dconnected(p, Y, observed=observed))
@@ -191,7 +193,8 @@ class CausalInference(object):
 
         Returns
         -------
-        boolean: True if Z is a valid frontdoor adjustment set.
+        Is valid frontdoor adjustment: bool
+            True if Z is a valid frontdoor adjustment set.
         """
         Z = _variable_or_iterable_to_set(Z)
 
@@ -228,9 +231,9 @@ class CausalInference(object):
 
     def get_all_frontdoor_adjustment_sets(self, X, Y):
         """
-        Identify possible sets of variables, Z, which satisify the front-door criterion relative to given X and Y.
+        Identify possible sets of variables, Z, which satisfy the front-door criterion relative to given X and Y.
 
-        Z satisifies the front-door critierion if:
+        Z satisfies the front-door criterion if:
           (i)    Z intercepts all directed paths from X to Y
           (ii)   there is no backdoor path from X to Z
           (iii)  all back-door paths from Z to Y are blocked by X
@@ -343,7 +346,7 @@ class CausalInference(object):
 
         Returns
         -------
-        float: The average treatment effect
+        The average treatment effect: float
 
         Examples
         --------
@@ -444,8 +447,9 @@ class CausalInference(object):
 
         Returns
         -------
-        boolean: Returns True if `adjustment_set` is a valid adjustment set for
-                identifying the effect of `X` on `Y`. Else returns False.
+        Is valid adjustment set: bool
+            Returns True if `adjustment_set` is a valid adjustment set for
+            identifying the effect of `X` on `Y`. Else returns False.
 
         Examples
         --------
@@ -482,8 +486,9 @@ class CausalInference(object):
 
         Returns
         -------
-        set or None: A set of variables which are the minimal possible adjustment set.
-                If None, no adjutment set is possible.
+        Minimal adjustment set: set or None
+            A set of variables which are the minimal possible adjustment set. If
+            None, no adjustment set is possible.
 
         Examples
         --------
@@ -540,8 +545,8 @@ class CausalInference(object):
 
         Returns
         -------
-        pgmpy.factor.DiscreteFactor: A factor object representing the joint distribution
-            over the variables in `variables`.
+        Queried distribution: pgmpy.factor.discrete.DiscreteFactor
+            A factor object representing the joint distribution over the variables in `variables`.
 
         Examples
         --------
