@@ -4,18 +4,25 @@ import itertools
 
 import networkx as nx
 import numpy as np
+from opt_einsum import contract
 from tqdm.auto import tqdm
 
 from pgmpy.factors import factor_product
+from pgmpy.factors.discrete import DiscreteFactor
+from pgmpy.global_vars import SHOW_PROGRESS
 from pgmpy.inference import Inference
 from pgmpy.inference.EliminationOrder import (
-    WeightedMinFill,
-    MinNeighbors,
     MinFill,
+    MinNeighbors,
     MinWeight,
+    WeightedMinFill,
+)
+from pgmpy.models import (
+    BayesianNetwork,
+    DynamicBayesianNetwork,
+    JunctionTree,
+    MarkovNetwork,
 )
-from pgmpy.models import JunctionTree, BayesianNetwork
-from pgmpy.global_vars import SHOW_PROGRESS
 
 
 class VariableElimination(Inference):
@@ -160,7 +167,7 @@ class VariableElimination(Inference):
         if isinstance(evidence, str):
             raise TypeError("evidence must be a list of strings")
 
-        # Dealing with the case when variables is not provided.
+        # Dealing with the case when variables are not provided.
         if not variables:
             all_factors = []
             for factor_li in self.factors.values():
@@ -216,11 +223,18 @@ class VariableElimination(Inference):
                 return factor_product(*final_distribution)
         else:
             query_var_factor = {}
-            for query_var in variables:
-                phi = factor_product(*final_distribution)
-                query_var_factor[query_var] = phi.marginalize(
-                    list(set(variables) - set([query_var])), inplace=False
-                ).normalize(inplace=False)
+            if isinstance(self.model, BayesianNetwork):
+                for query_var in variables:
+                    phi = factor_product(*final_distribution)
+                    query_var_factor[query_var] = phi.marginalize(
+                        list(set(variables) - set([query_var])), inplace=False
+                    ).normalize(inplace=False)
+            else:
+                for query_var in variables:
+                    phi = factor_product(*final_distribution)
+                    query_var_factor[query_var] = phi.marginalize(
+                        list(set(variables) - set([query_var])), inplace=False
+                    )
             return query_var_factor
 
     def query(
@@ -228,7 +242,7 @@ class VariableElimination(Inference):
         variables,
         evidence=None,
         virtual_evidence=None,
-        elimination_order="MinFill",
+        elimination_order="greedy",
         joint=True,
         show_progress=True,
     ):
@@ -246,9 +260,12 @@ class VariableElimination(Inference):
             A list of pgmpy.factors.discrete.TabularCPD representing the virtual
             evidences.
 
-        elimination_order: str or list
-            order of variable eliminations (if nothing is provided) order is
-            computed automatically.
+        elimination_order: str or list (default='greedy')
+            Order in which to eliminate the variables in the algorithm. If list is provided,
+            should contain all variables in the model except the ones in `variables`. str options
+            are: `greedy`, `WeightedMinFill`, `MinNeighbors`, `MinWeight`, `MinFill`. Please
+            refer https://pgmpy.org/exact_infer/ve.html#module-pgmpy.inference.EliminationOrder
+            for details.
 
         joint: boolean (default: True)
             If True, returns a Joint Distribution over `variables`.
@@ -271,7 +288,6 @@ class VariableElimination(Inference):
         >>> phi_query = inference.query(['A', 'B'])
         """
         evidence = evidence if evidence is not None else dict()
-        orig_model = self.model.copy()
 
         # Step 1: Parameter Checks
         common_vars = set(evidence if evidence is not None else []).intersection(
@@ -282,7 +298,7 @@ class VariableElimination(Inference):
                 f"Can't have the same variables in both `variables` and `evidence`. Found in both: {common_vars}"
             )
 
-        # Step 2: If virtual_evidence is provided, modify the network and query.
+        # Step 2: If virtual_evidence is provided, modify the network.
         if isinstance(self.model, BayesianNetwork) and (virtual_evidence is not None):
             self._virtual_evidence(virtual_evidence)
             virt_evidence = {"__" + cpd.variables[0]: 0 for cpd in virtual_evidence}
@@ -296,21 +312,108 @@ class VariableElimination(Inference):
             )
 
         # Step 3: Prune the network based on variables and evidence.
-        # Make a copy of the original model as it will be replaced during pruning.
         if isinstance(self.model, BayesianNetwork):
-            self.model, evidence = self._prune_bayesian_model(variables, evidence)
-        self._initialize_structures()
+            model_reduced, evidence = self._prune_bayesian_model(variables, evidence)
+            factors = model_reduced.cpds
+        else:
+            model_reduced = self.model
+            factors = self.model.factors
 
-        # Step 4: Do the actual variable elimination
-        result = self._variable_elimination(
-            variables=variables,
-            operation="marginalize",
-            evidence=evidence,
-            elimination_order=elimination_order,
-            joint=joint,
-            show_progress=show_progress,
-        )
-        self.__init__(orig_model)
+        # Step 4: If elimination_order is greedy, do a tensor contraction approach
+        #         else do the classic Variable Elimination.
+        if elimination_order == "greedy":
+            # Step 5.1: Compute the values array for factors after reducing them to provided
+            #           evidence.
+            evidence_vars = set(evidence)
+            reduce_indexes = []
+            reshape_indexes = []
+            for phi in factors:
+                indexes_to_reduce = [
+                    phi.variables.index(var)
+                    for var in set(phi.variables).intersection(evidence_vars)
+                ]
+                indexer = [slice(None)] * len(phi.variables)
+                for index in indexes_to_reduce:
+                    indexer[index] = phi.get_state_no(
+                        phi.variables[index], evidence[phi.variables[index]]
+                    )
+                reduce_indexes.append(tuple(indexer))
+                reshape_indexes.append(
+                    [
+                        1 if indexer != slice(None) else phi.cardinality[i]
+                        for i, indexer in enumerate(reduce_indexes[-1])
+                    ]
+                )
+
+            # Step 5.2: Prepare values and index arrays to do use in einsum
+            if isinstance(self.model, JunctionTree):
+                var_int_map = {
+                    var: i
+                    for i, var in enumerate(
+                        set(itertools.chain(*model_reduced.nodes()))
+                    )
+                }
+            else:
+                var_int_map = {var: i for i, var in enumerate(model_reduced.nodes())}
+            einsum_expr = []
+            for index, phi in enumerate(factors):
+                if not set(reshape_indexes[index]) == {1}:
+                    einsum_expr.append(
+                        (phi.values[reduce_indexes[index]]).reshape(
+                            reshape_indexes[index]
+                        )
+                    )
+                    einsum_expr.append([var_int_map[var] for var in phi.variables])
+            result_values = contract(
+                *einsum_expr, [var_int_map[var] for var in variables], optimize="greedy"
+            )
+
+            # Step 5.3: Prepare return values.
+            result = DiscreteFactor(
+                variables,
+                result_values.shape,
+                result_values,
+                state_names={var: model_reduced.states[var] for var in variables},
+            )
+            if joint:
+                if isinstance(
+                    self.model, (BayesianNetwork, JunctionTree, DynamicBayesianNetwork)
+                ):
+                    return result.normalize(inplace=False)
+                else:
+                    return result
+            else:
+                result_dict = {}
+                all_vars = set(variables)
+                if isinstance(
+                    self.model, (BayesianNetwork, JunctionTree, DynamicBayesianNetwork)
+                ):
+                    for var in variables:
+                        result_dict[var] = result.marginalize(
+                            all_vars - {var}, inplace=False
+                        ).normalize(inplace=False)
+                else:
+                    for var in variables:
+                        result_dict[var] = result.marginalize(
+                            all_vars - {var}, inplace=False
+                        )
+
+                return result_dict
+
+        else:
+            # Step 5.1: Initialize data structures for the reduced bn.
+            reduced_ve = VariableElimination(model_reduced)
+            reduced_ve._initialize_structures()
+
+            # Step 5.2: Do the actual variable elimination
+            result = reduced_ve._variable_elimination(
+                variables=variables,
+                operation="marginalize",
+                evidence=evidence,
+                elimination_order=elimination_order,
+                joint=joint,
+                show_progress=show_progress,
+            )
 
         return result
 
@@ -361,13 +464,15 @@ class VariableElimination(Inference):
                 f"Can't have the same variables in both `variables` and `evidence`. Found in both: {common_vars}"
             )
 
-        # Make a copy of the original model and replace self.model with it later.
-        orig_model = self.model.copy()
         if isinstance(self.model, BayesianNetwork):
-            self.model, evidence = self._prune_bayesian_model(variables, evidence)
-        self._initialize_structures()
+            model_reduced, evidence = self._prune_bayesian_model(variables, evidence)
+        else:
+            model_reduced = self.model
 
-        final_distribution = self._variable_elimination(
+        reduced_ve = VariableElimination(model_reduced)
+        reduced_ve._initialize_structures()
+
+        final_distribution = reduced_ve._variable_elimination(
             variables=variables,
             operation="maximize",
             evidence=evidence,
@@ -375,7 +480,6 @@ class VariableElimination(Inference):
             show_progress=show_progress,
         )
 
-        self.__init__(orig_model)
         return np.max(final_distribution.values)
 
     def map_query(
@@ -435,9 +539,6 @@ class VariableElimination(Inference):
                 f"Can't have the same variables in both `variables` and `evidence`. Found in both: {common_vars}"
             )
 
-        # Make a copy of the original model and replace self.model with it later
-        orig_model = self.model.copy()
-
         if isinstance(self.model, BayesianNetwork) and (virtual_evidence is not None):
             self._virtual_evidence(virtual_evidence)
             virt_evidence = {"__" + cpd.variables[0]: 0 for cpd in virtual_evidence}
@@ -450,11 +551,15 @@ class VariableElimination(Inference):
             )
 
         if isinstance(self.model, BayesianNetwork):
-            self.model, evidence = self._prune_bayesian_model(variables, evidence)
-        self._initialize_structures()
+            model_reduced, evidence = self._prune_bayesian_model(variables, evidence)
+        else:
+            model_reduced = self.model
+
+        reduced_ve = VariableElimination(model_reduced)
+        reduced_ve._initialize_structures()
 
         # TODO:Check the note in docstring. Change that behavior to return the joint MAP
-        final_distribution = self._variable_elimination(
+        final_distribution = reduced_ve._variable_elimination(
             variables=variables,
             operation="marginalize",
             evidence=evidence,
@@ -462,7 +567,6 @@ class VariableElimination(Inference):
             joint=True,
             show_progress=show_progress,
         )
-        self.__init__(orig_model)
 
         argmax = np.argmax(final_distribution.values)
         assignment = final_distribution.assignment([argmax])[0]
@@ -616,7 +720,7 @@ class BeliefPropagation(Inference):
         """
         return self.sepset_beliefs
 
-    def _update_beliefs(self, sending_clique, recieving_clique, operation):
+    def _update_beliefs(self, sending_clique, receiving_clique, operation):
         """
         This is belief-update method.
 
@@ -624,7 +728,7 @@ class BeliefPropagation(Inference):
         ----------
         sending_clique: node (as the operation is on junction tree, node should be a tuple)
             Node sending the message
-        recieving_clique: node (as the operation is on junction tree, node should be a tuple)
+        receiving_clique: node (as the operation is on junction tree, node should be a tuple)
             Node receiving the message
         operation: str ('marginalize' | 'maximize')
             The operation to do for passing messages between nodes.
@@ -632,8 +736,8 @@ class BeliefPropagation(Inference):
         Takes belief of one clique and uses it to update the belief of the
         neighboring ones.
         """
-        sepset = frozenset(sending_clique).intersection(frozenset(recieving_clique))
-        sepset_key = frozenset((sending_clique, recieving_clique))
+        sepset = frozenset(sending_clique).intersection(frozenset(receiving_clique))
+        sepset_key = frozenset((sending_clique, receiving_clique))
 
         # \sigma_{i \rightarrow j} = \sum_{C_i - S_{i, j}} \beta_i
         # marginalize the clique over the sepset
@@ -642,7 +746,7 @@ class BeliefPropagation(Inference):
         )
 
         # \beta_j = \beta_j * \frac{\sigma_{i \rightarrow j}}{\mu_{i, j}}
-        self.clique_beliefs[recieving_clique] *= (
+        self.clique_beliefs[receiving_clique] *= (
             sigma / self.sepset_beliefs[sepset_key]
             if self.sepset_beliefs[sepset_key]
             else sigma
@@ -727,7 +831,7 @@ class BeliefPropagation(Inference):
         for clique in self.junction_tree.nodes():
             if not self._is_converged(operation=operation):
                 neighbors = self.junction_tree.neighbors(clique)
-                # update root's belief using nieighbor clique's beliefs
+                # update root's belief using neighbor clique's beliefs
                 # upward pass
                 for neighbor_clique in neighbors:
                     self._update_beliefs(neighbor_clique, clique, operation=operation)
@@ -891,7 +995,7 @@ class BeliefPropagation(Inference):
         clique_potential_list = [self.clique_beliefs[root_node]]
 
         # For other nodes in the subtree compute the clique potentials as follows
-        # As all the nodes are nothing but tuples so simple set(root_node) won't work at it would update the set with'
+        # As all the nodes are nothing but tuples so simple set(root_node) won't work at it would update the set with
         # all the elements of the tuple; instead use set([root_node]) as it would include only the tuple not the
         # internal elements within it.
         parent_nodes = set([root_node])
