@@ -2,19 +2,18 @@ from .base import Inference
 from .CausalInference import CausalInference
 from .ExactInference import BeliefPropagation
 from .ExactInference import VariableElimination
+from .ApproxInference import ApproxInference
 from .dbn_inference import DBNInference
-from .bn_inference import BayesianModelInference, BayesianModelProbability
 from .mplp import Mplp
 
 __all__ = [
     "Inference",
     "VariableElimination",
     "DBNInference",
-    "BayesianModelInference",
-    "BayesianModelProbability",
     "BeliefPropagation",
     "BayesianModelSampling",
     "CausalInference",
+    "ApproxInference",
     "GibbsSampling",
     "Mplp",
     "continuous",
