@@ -1,24 +1,24 @@
 #!/usr/bin/env python3
 
 import itertools
-from collections import defaultdict
 import logging
-from operator import mul
+from collections import defaultdict
 from functools import reduce
+from operator import mul
 
 import networkx as nx
 import numpy as np
 import pandas as pd
-from tqdm.auto import tqdm
 from joblib import Parallel, delayed
+from tqdm.auto import tqdm
 
 from pgmpy.base import DAG
-from pgmpy.factors.discrete import (
-    TabularCPD,
-    JointProbabilityDistribution,
-    DiscreteFactor,
-)
 from pgmpy.factors.continuous import ContinuousFactor
+from pgmpy.factors.discrete import (
+    DiscreteFactor,
+    JointProbabilityDistribution,
+    TabularCPD,
+)
 from pgmpy.models.MarkovNetwork import MarkovNetwork
 
 
@@ -133,7 +133,7 @@ class BayesianNetwork(DAG):
         Remove node from the model.
 
         Removing a node also removes all the associated edges, removes the CPD
-        of the node and marginalizes the CPDs of it's children.
+        of the node and marginalizes the CPDs of its children.
 
         Parameters
         ----------
@@ -184,7 +184,7 @@ class BayesianNetwork(DAG):
         Remove multiple nodes from the model.
 
         Removing a node also removes all the associated edges, removes the CPD
-        of the node and marginalizes the CPDs of it's children.
+        of the node and marginalizes the CPDs of its children.
 
         Parameters
         ----------
@@ -278,7 +278,7 @@ class BayesianNetwork(DAG):
 
         Returns
         -------
-        A list of TabularCPDs.
+        A list of TabularCPDs: list
 
         Examples
         --------
@@ -323,7 +323,7 @@ class BayesianNetwork(DAG):
         >>> student.remove_cpds(cpd)
         """
         for cpd in cpds:
-            if isinstance(cpd, str):
+            if isinstance(cpd, (str, int)):
                 cpd = self.get_cpds(cpd)
             self.cpds.remove(cpd)
 
@@ -341,9 +341,9 @@ class BayesianNetwork(DAG):
 
         Returns
         -------
-        int or dict : If node is specified returns the cardinality of the node.
-                      If node is not specified returns a dictionary with the given
-                      variable as keys and their respective cardinality as values.
+        variable cardinalities: dict or int
+            If node is specified returns the cardinality of the node else returns a dictionary
+            with the cardinality of each variable in the network
 
         Examples
         --------
@@ -363,7 +363,7 @@ class BayesianNetwork(DAG):
         2
         """
 
-        if node:
+        if node is not None:
             return self.get_cpds(node).cardinality[0]
         else:
             cardinalities = defaultdict(int)
@@ -398,7 +398,7 @@ class BayesianNetwork(DAG):
         Returns
         -------
         check: boolean
-            True if all the checks are passed
+            True if all the checks pass otherwise should throw an error.
         """
         for node in self.nodes():
             cpd = self.get_cpds(node=node)
@@ -412,7 +412,7 @@ class BayesianNetwork(DAG):
                 evidence = cpd.get_evidence()
                 parents = self.get_parents(node)
 
-                # Check if the evidence set of the CPD is same as it's parents.
+                # Check if the evidence set of the CPD is same as its parents.
                 if set(evidence) != set(parents):
                     raise ValueError(
                         f"CPD associated with {node} doesn't have proper parents associated with it."
@@ -421,12 +421,12 @@ class BayesianNetwork(DAG):
                 # Check if the values of the CPD sum to 1.
                 if not cpd.is_valid_cpd():
                     raise ValueError(
-                        f"Sum or integral of conditional probabilites for node {node} is not equal to 1."
+                        f"Sum or integral of conditional probabilities for node {node} is not equal to 1."
                     )
 
                 if len(set(cpd.variables) - set(cpd.state_names.keys())) > 0:
                     raise ValueError(
-                        "CPD for {node} doesn't have state names defined for all the variables."
+                        f"CPD for {node} doesn't have state names defined for all the variables."
                     )
 
         for node in self.nodes():
@@ -553,7 +553,8 @@ class BayesianNetwork(DAG):
 
         Returns
         -------
-        None: Modifies the network inplace and adds the `cpds` property.
+        Fitted Model: None
+            Modifies the network inplace and adds the `cpds` property.
 
         Examples
         --------
@@ -568,7 +569,7 @@ class BayesianNetwork(DAG):
         <TabularCPD representing P(B:2) at 0x7fb98a7d5588>,
         <TabularCPD representing P(C:2 | A:2, B:2) at 0x7fb98a7b1f98>]
         """
-        from pgmpy.estimators import MaximumLikelihoodEstimator, BaseEstimator
+        from pgmpy.estimators import BaseEstimator, MaximumLikelihoodEstimator
 
         if estimator is None:
             estimator = MaximumLikelihoodEstimator
@@ -608,7 +609,8 @@ class BayesianNetwork(DAG):
 
         Returns
         -------
-        None: Modifies the network inplace
+        Updated model: None
+            Modifies the network inplace.
 
         Examples
         --------
@@ -653,8 +655,9 @@ class BayesianNetwork(DAG):
 
         stochastic: boolean
             If True, does prediction by sampling from the distribution of predicted variable(s).
-            If False, returns the states with the highest probability value (i.e MAP) for the
-                    predicted variable(s).
+            If False, returns the states with the highest probability value (i.e. MAP) for the
+                predicted variable(s).
+
         n_jobs: int (default: -1)
             The number of CPU cores to use. If -1, uses all available cores.
 
@@ -741,7 +744,9 @@ class BayesianNetwork(DAG):
 
             df_results = pd.DataFrame(pred_values, index=data_unique.index)
             data_with_results = pd.concat([data_unique, df_results], axis=1)
-            return data.merge(data_with_results, how="left").loc[:, missing_variables]
+            return data.merge(data_with_results, how="left").loc[
+                :, list(missing_variables)
+            ]
 
     def predict_probability(self, data):
         """
@@ -828,13 +833,12 @@ class BayesianNetwork(DAG):
 
         Parameters
         ----------
-        JPD : An instance of JointProbabilityDistribution Class, for which you want to
-            check the Imap
+        JPD: An instance of JointProbabilityDistribution Class, for which you want to check the Imap
 
         Returns
         -------
-        boolean : True if bayesian model is Imap for given Joint Probability Distribution
-                False otherwise
+        is IMAP: True or False
+            True if bayesian model is Imap for given Joint Probability Distribution False otherwise
 
         Examples
         --------
@@ -873,7 +877,8 @@ class BayesianNetwork(DAG):
 
         Returns
         -------
-        BayesianNetwork: Copy of the model on which the method was called.
+        Model's copy: pgmpy.models.BayesianNetwork
+            Copy of the model on which the method was called.
 
         Examples
         --------
@@ -912,7 +917,8 @@ class BayesianNetwork(DAG):
 
         Returns
         -------
-        list(blanket_nodes): List of nodes contained in Markov Blanket
+        Markov Blanket: list
+            List of nodes contained in Markov Blanket of `node`
 
         Parameters
         ----------
@@ -961,7 +967,8 @@ class BayesianNetwork(DAG):
 
         Returns
         -------
-        pgmpy.base.DAG instance: The randomly generated DAG.
+        Random DAG: pgmpy.base.DAG
+            The randomly generated DAG.
 
         Examples
         --------
@@ -1003,6 +1010,44 @@ class BayesianNetwork(DAG):
         bn_model.add_cpds(*cpds)
         return bn_model
 
+    def get_random_cpds(self, n_states=None, inplace=False):
+        """
+        Given a `model`, generates and adds random `TabularCPD` for each node resulting in a fully parameterized network.
+
+        Parameters
+        ----------
+        n_states: int or dict (default: None)
+            The number of states of each variable in the `model`. If None, randomly
+            generates the number of states.
+
+        inplace: bool (default: False)
+            If inplace=True, adds the generated TabularCPDs to `model` itself, else creates
+            a copy of the model.
+        """
+        if isinstance(n_states, int):
+            n_states = {var: n_states for var in self.nodes()}
+        elif isinstance(n_states, dict):
+            if set(n_states.keys()) != set(self.nodes()):
+                raise ValueError("Number of states not specified for each variable")
+        elif n_states is None:
+            n_states = {
+                var: np.random.randint(low=1, high=5, size=1)[0] for var in self.nodes()
+            }
+
+        model = self if inplace else self.copy()
+        cpds = []
+        for node in model.nodes():
+            parents = list(model.predecessors(node))
+            cpds.append(
+                TabularCPD.get_random(
+                    variable=node, evidence=parents, cardinality=n_states
+                )
+            )
+
+        model.add_cpds(*cpds)
+        if not inplace:
+            return model
+
     def do(self, nodes, inplace=False):
         """
         Applies the do operation. The do operation removes all incoming edges
@@ -1020,12 +1065,20 @@ class BayesianNetwork(DAG):
 
         Returns
         -------
-        pgmpy.models.BayesianNetwork: Instance of BayesianNetwork modified by the
-            do operation
+        Modified network: pgmpy.models.BayesianNetwork or None
+            If inplace=True, modifies the object itself else returns an instance of
+            BayesianNetwork modified by the do operation.
 
         Examples
         --------
-
+        >>> from pgmpy.utils import get_example_model
+        >>> asia = get_example_model('asia')
+        >>> asia.edges()
+        OutEdgeView([('asia', 'tub'), ('tub', 'either'), ('smoke', 'lung'), ('smoke', 'bronc'),
+                     ('lung', 'either'), ('bronc', 'dysp'), ('either', 'xray'), ('either', 'dysp')])
+        >>> do_bronc = asia.do(['bronc'])
+        OutEdgeView([('asia', 'tub'), ('tub', 'either'), ('smoke', 'lung'), ('lung', 'either'),
+                     ('bronc', 'dysp'), ('either', 'xray'), ('either', 'dysp')])
         """
         if isinstance(nodes, (str, int)):
             nodes = [nodes]
@@ -1101,28 +1154,33 @@ class BayesianNetwork(DAG):
 
         Returns
         -------
-        pandas.DataFrame: A dataframe with the simulated data.
+        A dataframe with the simulated data: pd.DataFrame
 
         Examples
         --------
         >>> from pgmpy.utils import get_example_model
 
-        Simulation without and evidence or intervention
+        Simulation without any evidence or intervention:
+
         >>> model = get_example_model('alarm')
         >>> model.simulate(n_samples=10)
 
-        Simulation with the hard evidence: MINVOLSET = HIGH
+        Simulation with the hard evidence: MINVOLSET = HIGH:
+
         >>> model.simulate(n_samples=10, evidence={"MINVOLSET": "HIGH"})
 
-        Simulation with hard intervention: CVP = LOW
+        Simulation with hard intervention: CVP = LOW:
+
         >>> model.simulate(n_samples=10, do={"CVP": "LOW"})
 
         Simulation with virtual/soft evidence: p(MINVOLSET=LOW) = 0.8, p(MINVOLSET=HIGH) = 0.2,
-        p(MINVOLSET=NORMAL) = 0
+        p(MINVOLSET=NORMAL) = 0:
+
         >>> virt_evidence = [TabularCPD("MINVOLSET", 3, [[0.8], [0.0], [0.2]], state_names={"MINVOLSET": ["LOW", "NORMAL", "HIGH"]})]
         >>> model.simulate(n_samples, virtual_evidence=virt_evidence)
 
-        Simulation with virtual/soft intervention: p(CVP=LOW) = 0.2, p(CVP=NORMAL)=0.5, p(CVP=HIGH)=0.3
+        Simulation with virtual/soft intervention: p(CVP=LOW) = 0.2, p(CVP=NORMAL)=0.5, p(CVP=HIGH)=0.3:
+
         >>> virt_intervention = [TabularCPD("CVP", 3, [[0.2], [0.5], [0.3]], state_names={"CVP": ["LOW", "NORMAL", "HIGH"]})]
         >>> model.simulate(n_samples, virtual_intervention=virt_intervention)
         """
@@ -1130,9 +1188,18 @@ class BayesianNetwork(DAG):
 
         self.check_model()
         model = self.copy()
+        state_names = self.states
 
         evidence = {} if evidence is None else evidence
+        for var, state in evidence.items():
+            if state not in state_names[var]:
+                raise ValueError(f"Evidence state: {state} for {var} doesn't exist")
+
         do = {} if do is None else do
+        for var, state in do.items():
+            if state not in state_names[var]:
+                raise ValueError(f"Do state: {state} for {var} doesn't exist")
+
         virtual_intervention = (
             [] if virtual_intervention is None else virtual_intervention
         )
@@ -1158,11 +1225,11 @@ class BayesianNetwork(DAG):
                     )
                 elif len(cpd.variables) > 1:
                     raise (
-                        "Virtual evidecne should be defined on individual variables. Maybe your are looking for soft evidence."
+                        "Virtual evidence should be defined on individual variables. Maybe you are looking for soft evidence."
                     )
                 elif self.get_cardinality(var) != cpd.get_cardinality([var])[var]:
                     raise ValueError(
-                        "The number of states/cardinality for the evideence should be same as the nubmer fo states/cardinalit yof teh variable in the model"
+                        "The number of states/cardinality for the evidence should be same as the number of states/cardinality of the variable in the model"
                     )
 
             for cpd in virtual_evidence:
@@ -1206,7 +1273,7 @@ class BayesianNetwork(DAG):
         if include_latents:
             return samples
         else:
-            return samples.loc[:, set(self.nodes()) - self.latents]
+            return samples.loc[:, list(set(self.nodes()) - self.latents)]
 
     def save(self, filename, filetype="bif"):
         """
