@@ -1,14 +1,12 @@
-import unittest
-import numpy as np
 import itertools
+import unittest
+
+import numpy as np
 import numpy.testing as np_test
 
-from pgmpy.inference import VariableElimination
-from pgmpy.inference import BeliefPropagation
-from pgmpy.models import BayesianNetwork, MarkovNetwork
-from pgmpy.models import JunctionTree
-from pgmpy.factors.discrete import TabularCPD
-from pgmpy.factors.discrete import DiscreteFactor
+from pgmpy.factors.discrete import DiscreteFactor, TabularCPD
+from pgmpy.inference import BeliefPropagation, VariableElimination
+from pgmpy.models import BayesianNetwork, JunctionTree, MarkovNetwork
 
 
 class TestVariableElimination(unittest.TestCase):
@@ -40,100 +38,180 @@ class TestVariableElimination(unittest.TestCase):
 
         self.bayesian_inference = VariableElimination(self.bayesian_model)
 
-    # All the values that are used for comparision in the all the tests are
+    # All the values that are used for comparison in the all the tests are
     # found using SAMIAM (assuming that it is correct ;))
 
     def test_query_single_variable(self):
-        query_result = self.bayesian_inference.query(["J"])
-        self.assertEqual(
-            query_result,
-            DiscreteFactor(variables=["J"], cardinality=[2], values=[0.416, 0.584]),
-        )
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            query_result = self.bayesian_inference.query(
+                ["J"], elimination_order=order, show_progress=False
+            )
+            self.assertEqual(
+                query_result,
+                DiscreteFactor(variables=["J"], cardinality=[2], values=[0.416, 0.584]),
+            )
 
     def test_query_multiple_variable(self):
-        query_result = self.bayesian_inference.query(["Q", "J"])
-        self.assertEqual(
-            query_result,
-            DiscreteFactor(
-                variables=["J", "Q"],
-                cardinality=[2, 2],
-                values=np.array([[0.3744, 0.0416], [0.1168, 0.4672]]),
-            ),
-        )
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            query_result = self.bayesian_inference.query(
+                ["Q", "J"], elimination_order=order, show_progress=False
+            )
+            self.assertEqual(
+                query_result,
+                DiscreteFactor(
+                    variables=["J", "Q"],
+                    cardinality=[2, 2],
+                    values=np.array([[0.3744, 0.0416], [0.1168, 0.4672]]),
+                ),
+            )
 
     def test_query_single_variable_with_evidence(self):
-        query_result = self.bayesian_inference.query(
-            variables=["J"], evidence={"A": 0, "R": 1}
-        )
-        self.assertEqual(
-            query_result,
-            DiscreteFactor(variables=["J"], cardinality=[2], values=[0.6, 0.4]),
-        )
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            query_result = self.bayesian_inference.query(
+                variables=["J"],
+                evidence={"A": 0, "R": 1},
+                elimination_order=order,
+                show_progress=False,
+            )
+            self.assertEqual(
+                query_result,
+                DiscreteFactor(variables=["J"], cardinality=[2], values=[0.6, 0.4]),
+            )
 
     def test_query_multiple_variable_with_evidence(self):
-        query_result = self.bayesian_inference.query(
-            variables=["J", "Q"], evidence={"A": 0, "R": 0, "G": 0, "L": 1}
-        )
-        self.assertEqual(
-            query_result,
-            DiscreteFactor(
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            query_result = self.bayesian_inference.query(
                 variables=["J", "Q"],
-                cardinality=[2, 2],
-                values=np.array([[0.73636364, 0.08181818], [0.03636364, 0.14545455]]),
-            ),
-        )
+                evidence={"A": 0, "R": 0, "G": 0, "L": 1},
+                elimination_order=order,
+                show_progress=False,
+            )
+            self.assertEqual(
+                query_result,
+                DiscreteFactor(
+                    variables=["J", "Q"],
+                    cardinality=[2, 2],
+                    values=np.array(
+                        [[0.73636364, 0.08181818], [0.03636364, 0.14545455]]
+                    ),
+                ),
+            )
 
     def test_query_multiple_times(self):
         # This just tests that the models are not getting modified while querying them
-        query_result = self.bayesian_inference.query(["J"])
-        query_result = self.bayesian_inference.query(["J"])
-        self.assertEqual(
-            query_result,
-            DiscreteFactor(
-                variables=["J"], cardinality=[2], values=np.array([0.416, 0.584])
-            ),
-        )
-        query_result = self.bayesian_inference.query(["Q", "J"])
-        query_result = self.bayesian_inference.query(["Q", "J"])
-        self.assertEqual(
-            query_result,
-            DiscreteFactor(
-                variables=["J", "Q"],
-                cardinality=[2, 2],
-                values=np.array([[0.3744, 0.0416], [0.1168, 0.4672]]),
-            ),
-        )
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            query_result = self.bayesian_inference.query(
+                ["J"], elimination_order=order, show_progress=False
+            )
+            query_result = self.bayesian_inference.query(
+                ["J"], elimination_order=order, show_progress=False
+            )
+            self.assertEqual(
+                query_result,
+                DiscreteFactor(
+                    variables=["J"], cardinality=[2], values=np.array([0.416, 0.584])
+                ),
+            )
+            query_result = self.bayesian_inference.query(
+                ["Q", "J"], elimination_order=order, show_progress=False
+            )
+            query_result = self.bayesian_inference.query(
+                ["Q", "J"], elimination_order=order, show_progress=False
+            )
+            self.assertEqual(
+                query_result,
+                DiscreteFactor(
+                    variables=["J", "Q"],
+                    cardinality=[2, 2],
+                    values=np.array([[0.3744, 0.0416], [0.1168, 0.4672]]),
+                ),
+            )
 
-        query_result = self.bayesian_inference.query(
-            variables=["J"], evidence={"A": 0, "R": 1}
-        )
-        query_result = self.bayesian_inference.query(
-            variables=["J"], evidence={"A": 0, "R": 1}
-        )
-        self.assertEqual(
-            query_result,
-            DiscreteFactor(variables=["J"], cardinality=[2], values=[0.6, 0.4]),
-        )
+            query_result = self.bayesian_inference.query(
+                variables=["J"],
+                evidence={"A": 0, "R": 1},
+                elimination_order=order,
+                show_progress=False,
+            )
+            query_result = self.bayesian_inference.query(
+                variables=["J"],
+                evidence={"A": 0, "R": 1},
+                elimination_order=order,
+                show_progress=False,
+            )
+            self.assertEqual(
+                query_result,
+                DiscreteFactor(variables=["J"], cardinality=[2], values=[0.6, 0.4]),
+            )
 
-        query_result = self.bayesian_inference.query(
-            variables=["J", "Q"], evidence={"A": 0, "R": 0, "G": 0, "L": 1}
-        )
-        query_result = self.bayesian_inference.query(
-            variables=["J", "Q"], evidence={"A": 0, "R": 0, "G": 0, "L": 1}
-        )
-        self.assertEqual(
-            query_result,
-            DiscreteFactor(
+            query_result = self.bayesian_inference.query(
                 variables=["J", "Q"],
-                cardinality=[2, 2],
-                values=np.array([[0.73636364, 0.08181818], [0.03636364, 0.14545455]]),
-            ),
-        )
+                evidence={"A": 0, "R": 0, "G": 0, "L": 1},
+                elimination_order=order,
+                show_progress=False,
+            )
+            query_result = self.bayesian_inference.query(
+                variables=["J", "Q"],
+                evidence={"A": 0, "R": 0, "G": 0, "L": 1},
+                elimination_order=order,
+                show_progress=False,
+            )
+            self.assertEqual(
+                query_result,
+                DiscreteFactor(
+                    variables=["J", "Q"],
+                    cardinality=[2, 2],
+                    values=np.array(
+                        [[0.73636364, 0.08181818], [0.03636364, 0.14545455]]
+                    ),
+                ),
+            )
 
     def test_query_common_var(self):
-        self.assertRaises(
-            ValueError, self.bayesian_inference.query, variables=["J"], evidence=["J"]
-        )
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            self.assertRaises(
+                ValueError,
+                self.bayesian_inference.query,
+                variables=["J"],
+                evidence=["J"],
+                elimination_order=order,
+            )
 
     def test_max_marginal(self):
         np_test.assert_almost_equal(
@@ -164,24 +242,41 @@ class TestVariableElimination(unittest.TestCase):
         )
 
     def test_map_query(self):
-        map_query = self.bayesian_inference.map_query()
-        self.assertDictEqual(
-            map_query, {"A": 1, "R": 1, "J": 1, "Q": 1, "G": 0, "L": 0}
-        )
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            map_query = self.bayesian_inference.map_query(
+                elimination_order=order, show_progress=False
+            )
+            self.assertDictEqual(
+                map_query, {"A": 1, "R": 1, "J": 1, "Q": 1, "G": 0, "L": 0}
+            )
 
     def test_map_query_with_evidence(self):
         map_query = self.bayesian_inference.map_query(
-            ["A", "R", "L"], {"J": 0, "Q": 1, "G": 0}
+            ["A", "R", "L"], {"J": 0, "Q": 1, "G": 0}, show_progress=False
         )
         self.assertDictEqual(map_query, {"A": 1, "R": 0, "L": 0})
 
     def test_map_query_common_var(self):
-        self.assertRaises(
-            ValueError,
-            self.bayesian_inference.map_query,
-            variables=["J"],
-            evidence=["J"],
-        )
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            self.assertRaises(
+                ValueError,
+                self.bayesian_inference.map_query,
+                variables=["J"],
+                evidence=["J"],
+                elimination_order=order,
+            )
 
     def test_elimination_order(self):
         # Check all the heuristics give the same results.
@@ -192,7 +287,7 @@ class TestVariableElimination(unittest.TestCase):
             "MinFill",
         ]:
             query_result = self.bayesian_inference.query(
-                ["J"], elimination_order=elimination_order
+                ["J"], elimination_order=elimination_order, show_progress=False
             )
             self.assertEqual(
                 query_result,
@@ -200,7 +295,7 @@ class TestVariableElimination(unittest.TestCase):
             )
 
             query_result = self.bayesian_inference.query(
-                variables=["J"], evidence={"A": 0, "R": 1}
+                variables=["J"], evidence={"A": 0, "R": 1}, show_progress=False
             )
             self.assertEqual(
                 query_result,
@@ -209,7 +304,7 @@ class TestVariableElimination(unittest.TestCase):
 
         # Check when elimination order has extra variables. Because of pruning.
         query_result = self.bayesian_inference.query(
-            ["J"], elimination_order=["A", "R", "L", "Q", "G"]
+            ["J"], elimination_order=["A", "R", "L", "Q", "G"], show_progress=False
         )
         self.assertEqual(
             query_result,
@@ -301,13 +396,19 @@ class TestSnowNetwork(unittest.TestCase):
     def test_queries(self):
         for algo in [VariableElimination, BeliefPropagation]:
             infer = algo(self.model)
-            query1 = infer.query(["Snow"], evidence={"Traffic": "slow"})
+            query1 = infer.query(
+                ["Snow"], evidence={"Traffic": "slow"}, show_progress=False
+            )
             np_test.assert_array_almost_equal(query1.values, [0.533333, 0.466667])
 
-            query2 = infer.query(["Risk"], evidence={"Traffic": "slow"})
+            query2 = infer.query(
+                ["Risk"], evidence={"Traffic": "slow"}, show_progress=False
+            )
             np_test.assert_array_almost_equal(query2.values, [0.613333, 0.386667])
 
-            query3 = infer.query(["Late"], evidence={"Traffic": "slow"})
+            query3 = infer.query(
+                ["Late"], evidence={"Traffic": "slow"}, show_progress=False
+            )
             np_test.assert_array_almost_equal(query3.values, [0.7920, 0.2080])
 
             self.assertRaises(
@@ -317,7 +418,7 @@ class TestSnowNetwork(unittest.TestCase):
                 evidence={"Traffic": "slow"},
             )
 
-    def test_get_elimination_order(self):
+    def test_elimination_order(self):
         infer = VariableElimination(self.model)
         for order in ["MinFill", "MinNeighbors", "MinWeight", "WeightedMinFill"]:
             computed_order = infer._get_elimination_order(
@@ -325,35 +426,105 @@ class TestSnowNetwork(unittest.TestCase):
             )
             self.assertEqual(set(computed_order), set({"Risk", "Late", "Snow"}))
 
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            query1 = infer.query(
+                ["Snow"],
+                evidence={"Traffic": "slow"},
+                elimination_order=order,
+                show_progress=False,
+            )
+            np_test.assert_array_almost_equal(query1.values, [0.533333, 0.466667])
+
+            query2 = infer.query(
+                ["Risk"],
+                evidence={"Traffic": "slow"},
+                elimination_order=order,
+                show_progress=False,
+            )
+            np_test.assert_array_almost_equal(query2.values, [0.613333, 0.386667])
+
+            query3 = infer.query(
+                ["Late"],
+                evidence={"Traffic": "slow"},
+                elimination_order=order,
+                show_progress=False,
+            )
+            np_test.assert_array_almost_equal(query3.values, [0.7920, 0.2080])
+
+    def test_joint_distribution(self):
+        infer = VariableElimination(self.model)
+        for order in [
+            "greedy",
+            "MinFill",
+            "MinNeighbors",
+            "MinWeight",
+            "WeightedMinFill",
+        ]:
+            query_expected = {}
+            query_expected["Snow"] = infer.query(
+                ["Snow"], elimination_order=order, show_progress=False
+            )
+            query_expected["Risk"] = infer.query(
+                ["Risk"], elimination_order=order, show_progress=False
+            )
+
+            query_joint = infer.query(
+                ["Snow", "Risk"], elimination_order=order, joint=False
+            )
+            for var in ["Snow", "Risk"]:
+                self.assertEqual(query_joint[var], query_expected[var])
+
     def test_virt_evidence(self):
         virt_evidence = TabularCPD(
             "Traffic", 2, [[0.3], [0.7]], state_names={"Traffic": ["normal", "slow"]}
         )
         for algo in [VariableElimination, BeliefPropagation]:
             infer = algo(self.model)
-            query1 = infer.query(["Snow"], virtual_evidence=[virt_evidence])
+            query1 = infer.query(
+                ["Snow"], virtual_evidence=[virt_evidence], show_progress=False
+            )
             np_test.assert_array_almost_equal(query1.values, [0.45, 0.55])
 
-            map1 = infer.map_query(["Snow"], virtual_evidence=[virt_evidence])
+            map1 = infer.map_query(
+                ["Snow"], virtual_evidence=[virt_evidence], show_progress=False
+            )
             self.assertEqual(map1, {"Snow": "no"})
 
-            query2 = infer.query(["Risk"], virtual_evidence=[virt_evidence])
+            query2 = infer.query(
+                ["Risk"], virtual_evidence=[virt_evidence], show_progress=False
+            )
             np_test.assert_array_almost_equal(query2.values, [0.58, 0.42])
 
-            map2 = infer.map_query(["Risk"], virtual_evidence=[virt_evidence])
+            map2 = infer.map_query(
+                ["Risk"], virtual_evidence=[virt_evidence], show_progress=False
+            )
             self.assertEqual(map2, {"Risk": "yes"})
 
-            query3 = infer.query(["Late"], virtual_evidence=[virt_evidence])
+            query3 = infer.query(
+                ["Late"], virtual_evidence=[virt_evidence], show_progress=False
+            )
             np_test.assert_array_almost_equal(query3.values, [0.61625, 0.38375])
 
-            map3 = infer.map_query(["Late"], virtual_evidence=[virt_evidence])
+            map3 = infer.map_query(
+                ["Late"], virtual_evidence=[virt_evidence], show_progress=False
+            )
             self.assertEqual(map3, {"Late": "yes"})
 
-            query4 = infer.query(["Traffic"], virtual_evidence=[virt_evidence])
+            query4 = infer.query(
+                ["Traffic"], virtual_evidence=[virt_evidence], show_progress=False
+            )
             np_test.assert_array_almost_equal(query4.values, [0.34375, 0.65625])
 
             # TODO: State name should be returned here.
-            map4 = infer.map_query(["Traffic"], virtual_evidence=[virt_evidence])
+            map4 = infer.map_query(
+                ["Traffic"], virtual_evidence=[virt_evidence], show_progress=False
+            )
             self.assertTrue(map4 in [{"Traffic": "slow"}, {"Traffic": 1}])
 
         virt_evidence1 = TabularCPD(
@@ -362,39 +533,55 @@ class TestSnowNetwork(unittest.TestCase):
         for algo in [VariableElimination, BeliefPropagation]:
             infer = algo(self.model)
             query1 = infer.query(
-                ["Snow"], virtual_evidence=[virt_evidence, virt_evidence1]
+                ["Snow"],
+                virtual_evidence=[virt_evidence, virt_evidence1],
+                show_progress=False,
             )
             np_test.assert_array_almost_equal(query1.values, [0.52443609, 0.47556391])
 
             map1 = infer.map_query(
-                ["Snow"], virtual_evidence=[virt_evidence, virt_evidence1]
+                ["Snow"],
+                virtual_evidence=[virt_evidence, virt_evidence1],
+                show_progress=False,
             )
             self.assertEqual(map1, {"Snow": "yes"})
 
             query2 = infer.query(
-                ["Risk"], virtual_evidence=[virt_evidence, virt_evidence1]
+                ["Risk"],
+                virtual_evidence=[virt_evidence, virt_evidence1],
+                show_progress=False,
             )
             np_test.assert_array_almost_equal(query2.values, [0.76315789, 0.23684211])
             map2 = infer.map_query(
-                ["Risk"], virtual_evidence=[virt_evidence, virt_evidence1]
+                ["Risk"],
+                virtual_evidence=[virt_evidence, virt_evidence1],
+                show_progress=False,
             )
             self.assertTrue(map2 in [{"Risk": 0}, {"Risk": "yes"}])
 
             query3 = infer.query(
-                ["Traffic"], virtual_evidence=[virt_evidence, virt_evidence1]
+                ["Traffic"],
+                virtual_evidence=[virt_evidence, virt_evidence1],
+                show_progress=False,
             )
             np_test.assert_array_almost_equal(query3.values, [0.32730263, 0.67269737])
             map3 = infer.map_query(
-                ["Traffic"], virtual_evidence=[virt_evidence, virt_evidence1]
+                ["Traffic"],
+                virtual_evidence=[virt_evidence, virt_evidence1],
+                show_progress=False,
             )
             self.assertTrue(map3 in [{"Traffic": "slow"}, {"Traffic": 1}])
 
             query4 = infer.query(
-                ["Late"], virtual_evidence=[virt_evidence, virt_evidence1]
+                ["Late"],
+                virtual_evidence=[virt_evidence, virt_evidence1],
+                show_progress=False,
             )
             np_test.assert_array_almost_equal(query4.values, [0.66480263, 0.33519737])
             map4 = infer.map_query(
-                ["Late"], virtual_evidence=[virt_evidence, virt_evidence1]
+                ["Late"],
+                virtual_evidence=[virt_evidence, virt_evidence1],
+                show_progress=False,
             )
             self.assertEqual(map4, {"Late": "yes"})
 
@@ -412,7 +599,7 @@ class TestVariableEliminationDuplicatedFactors(unittest.TestCase):
         self.markov_inference = VariableElimination(self.markov_model)
 
     def test_duplicated_factors(self):
-        query_result = self.markov_inference.query(["A"])
+        query_result = self.markov_inference.query(["A"], show_progress=False)
         self.assertEqual(
             query_result,
             DiscreteFactor(variables=["A"], cardinality=[2], values=np.array([4, 4])),
@@ -461,11 +648,11 @@ class TestVariableEliminationMarkov(unittest.TestCase):
         )
         self.markov_inference = VariableElimination(self.markov_model)
 
-    # All the values that are used for comparision in the all the tests are
+    # All the values that are used for comparison in the all the tests are
     # found using SAMIAM (assuming that it is correct ;))
 
     def test_query_single_variable(self):
-        query_result = self.markov_inference.query(["J"])
+        query_result = self.markov_inference.query(["J"], show_progress=False)
         self.assertEqual(
             query_result,
             DiscreteFactor(
@@ -474,7 +661,7 @@ class TestVariableEliminationMarkov(unittest.TestCase):
         )
 
     def test_query_multiple_variable(self):
-        query_result = self.markov_inference.query(["Q", "J"])
+        query_result = self.markov_inference.query(["Q", "J"], show_progress=False)
         self.assertEqual(
             query_result,
             DiscreteFactor(
@@ -486,7 +673,7 @@ class TestVariableEliminationMarkov(unittest.TestCase):
 
     def test_query_single_variable_with_evidence(self):
         query_result = self.markov_inference.query(
-            variables=["J"], evidence={"A": 0, "R": 1}
+            variables=["J"], evidence={"A": 0, "R": 1}, show_progress=False
         )
         self.assertEqual(
             query_result,
@@ -495,21 +682,23 @@ class TestVariableEliminationMarkov(unittest.TestCase):
 
     def test_query_multiple_variable_with_evidence(self):
         query_result = self.markov_inference.query(
-            variables=["J", "Q"], evidence={"A": 0, "R": 0, "G": 0, "L": 1}
+            variables=["J", "Q"],
+            evidence={"A": 0, "R": 0, "G": 0, "L": 1},
+            show_progress=False,
         )
         self.assertEqual(
             query_result,
             DiscreteFactor(
-                variables=["Q", "J"],
+                variables=["J", "Q"],
                 cardinality=[2, 2],
-                values=np.array([[0.081, 0.004], [0.009, 0.016]]),
+                values=np.array([[0.081, 0.009], [0.004, 0.016]]),
             ),
         )
 
     def test_query_multiple_times(self):
         # This just tests that the models are not getting modified while querying them
-        query_result = self.markov_inference.query(["J"])
-        query_result = self.markov_inference.query(["J"])
+        query_result = self.markov_inference.query(["J"], show_progress=False)
+        query_result = self.markov_inference.query(["J"], show_progress=False)
         self.assertEqual(
             query_result,
             DiscreteFactor(
@@ -517,8 +706,8 @@ class TestVariableEliminationMarkov(unittest.TestCase):
             ),
         )
 
-        query_result = self.markov_inference.query(["Q", "J"])
-        query_result = self.markov_inference.query(["Q", "J"])
+        query_result = self.markov_inference.query(["Q", "J"], show_progress=False)
+        query_result = self.markov_inference.query(["Q", "J"], show_progress=False)
         self.assertEqual(
             query_result,
             DiscreteFactor(
@@ -529,10 +718,10 @@ class TestVariableEliminationMarkov(unittest.TestCase):
         )
 
         query_result = self.markov_inference.query(
-            variables=["J"], evidence={"A": 0, "R": 1}
+            variables=["J"], evidence={"A": 0, "R": 1}, show_progress=False
         )
         query_result = self.markov_inference.query(
-            variables=["J"], evidence={"A": 0, "R": 1}
+            variables=["J"], evidence={"A": 0, "R": 1}, show_progress=False
         )
         self.assertEqual(
             query_result,
@@ -540,17 +729,21 @@ class TestVariableEliminationMarkov(unittest.TestCase):
         )
 
         query_result = self.markov_inference.query(
-            variables=["J", "Q"], evidence={"A": 0, "R": 0, "G": 0, "L": 1}
+            variables=["J", "Q"],
+            evidence={"A": 0, "R": 0, "G": 0, "L": 1},
+            show_progress=False,
         )
         query_result = self.markov_inference.query(
-            variables=["J", "Q"], evidence={"A": 0, "R": 0, "G": 0, "L": 1}
+            variables=["J", "Q"],
+            evidence={"A": 0, "R": 0, "G": 0, "L": 1},
+            show_progress=False,
         )
         self.assertEqual(
             query_result,
             DiscreteFactor(
-                variables=["Q", "J"],
+                variables=["J", "Q"],
                 cardinality=[2, 2],
-                values=np.array([[0.081, 0.004], [0.009, 0.016]]),
+                values=np.array([[0.081, 0.009], [0.004, 0.016]]),
             ),
         )
 
@@ -575,14 +768,14 @@ class TestVariableEliminationMarkov(unittest.TestCase):
         )
 
     def test_map_query(self):
-        map_query = self.markov_inference.map_query()
+        map_query = self.markov_inference.map_query(show_progress=False)
         self.assertDictEqual(
             map_query, {"A": 1, "R": 1, "J": 1, "Q": 1, "G": 0, "L": 0}
         )
 
     def test_map_query_with_evidence(self):
         map_query = self.markov_inference.map_query(
-            ["A", "R", "L"], {"J": 0, "Q": 1, "G": 0}
+            ["A", "R", "L"], {"J": 0, "Q": 1, "G": 0}, show_progress=False
         )
         self.assertDictEqual(map_query, {"A": 1, "R": 0, "L": 0})
 
@@ -636,7 +829,8 @@ class TestVariableEliminationMarkov(unittest.TestCase):
 
         infer = VariableElimination(model)
         np_test.assert_array_almost_equal(
-            infer.query(["Y"], evidence={"X": 0}).values, [0.35, 0.65]
+            infer.query(["Y"], evidence={"X": 0}, show_progress=False).values,
+            [0.35, 0.65],
         )
 
     def tearDown(self):
@@ -699,15 +893,9 @@ class TestBeliefPropagation(unittest.TestCase):
             ["B"], inplace=False
         )
 
-        np_test.assert_array_almost_equal(
-            clique_belief[("A", "B")].values, b_A_B.values
-        )
-        np_test.assert_array_almost_equal(
-            clique_belief[("B", "C")].values, b_B_C.values
-        )
-        np_test.assert_array_almost_equal(
-            clique_belief[("C", "D")].values, b_C_D.values
-        )
+        self.assertEqual(clique_belief[("A", "B")], b_A_B)
+        self.assertEqual(clique_belief[("B", "C")], b_B_C)
+        self.assertEqual(clique_belief[("C", "D")], b_C_D)
 
     def test_calibrate_sepset_belief(self):
         belief_propagation = BeliefPropagation(self.junction_tree)
@@ -759,15 +947,9 @@ class TestBeliefPropagation(unittest.TestCase):
             ["B"], inplace=False
         )
 
-        np_test.assert_array_almost_equal(
-            clique_belief[("A", "B")].values, b_A_B.values
-        )
-        np_test.assert_array_almost_equal(
-            clique_belief[("B", "C")].values, b_B_C.values
-        )
-        np_test.assert_array_almost_equal(
-            clique_belief[("C", "D")].values, b_C_D.values
-        )
+        self.assertEqual(clique_belief[("A", "B")], b_A_B)
+        self.assertEqual(clique_belief[("B", "C")], b_B_C)
+        self.assertEqual(clique_belief[("C", "D")], b_C_D)
 
     def test_max_calibrate_sepset_belief(self):
         belief_propagation = BeliefPropagation(self.junction_tree)
@@ -800,12 +982,12 @@ class TestBeliefPropagation(unittest.TestCase):
             sepset_belief[frozenset((("B", "C"), ("C", "D")))].values, b_C.values
         )
 
-    # All the values that are used for comparision in the all the tests are
+    # All the values that are used for comparison in the all the tests are
     # found using SAMIAM (assuming that it is correct ;))
 
     def test_query_single_variable(self):
         belief_propagation = BeliefPropagation(self.bayesian_model)
-        query_result = belief_propagation.query(["J"])
+        query_result = belief_propagation.query(["J"], show_progress=False)
         self.assertEqual(
             query_result,
             DiscreteFactor(variables=["J"], cardinality=[2], values=[0.416, 0.584]),
@@ -813,7 +995,7 @@ class TestBeliefPropagation(unittest.TestCase):
 
     def test_query_multiple_variable(self):
         belief_propagation = BeliefPropagation(self.bayesian_model)
-        query_result = belief_propagation.query(["Q", "J"])
+        query_result = belief_propagation.query(["Q", "J"], show_progress=False)
         self.assertEqual(
             query_result,
             DiscreteFactor(
@@ -826,7 +1008,7 @@ class TestBeliefPropagation(unittest.TestCase):
     def test_query_single_variable_with_evidence(self):
         belief_propagation = BeliefPropagation(self.bayesian_model)
         query_result = belief_propagation.query(
-            variables=["J"], evidence={"A": 0, "R": 1}
+            variables=["J"], evidence={"A": 0, "R": 1}, show_progress=False
         )
         self.assertEqual(
             query_result,
@@ -838,7 +1020,9 @@ class TestBeliefPropagation(unittest.TestCase):
     def test_query_multiple_variable_with_evidence(self):
         belief_propagation = BeliefPropagation(self.bayesian_model)
         query_result = belief_propagation.query(
-            variables=["J", "Q"], evidence={"A": 0, "R": 0, "G": 0, "L": 1}
+            variables=["J", "Q"],
+            evidence={"A": 0, "R": 0, "G": 0, "L": 1},
+            show_progress=False,
         )
         self.assertEqual(
             query_result,
@@ -857,7 +1041,7 @@ class TestBeliefPropagation(unittest.TestCase):
 
     def test_map_query(self):
         belief_propagation = BeliefPropagation(self.bayesian_model)
-        map_query = belief_propagation.map_query()
+        map_query = belief_propagation.map_query(show_progress=False)
         self.assertDictEqual(
             map_query, {"A": 1, "R": 1, "J": 1, "Q": 1, "G": 0, "L": 0}
         )
@@ -865,7 +1049,7 @@ class TestBeliefPropagation(unittest.TestCase):
     def test_map_query_with_evidence(self):
         belief_propagation = BeliefPropagation(self.bayesian_model)
         map_query = belief_propagation.map_query(
-            ["A", "R", "L"], {"J": 0, "Q": 1, "G": 0}
+            ["A", "R", "L"], {"J": 0, "Q": 1, "G": 0}, show_progress=False
         )
         self.assertDictEqual(map_query, {"A": 1, "R": 0, "L": 0})
 
@@ -915,7 +1099,9 @@ class TestBeliefPropagation(unittest.TestCase):
         for i, c in enumerate(children[:4]):
             self.assertEqual(evidence, expected_evidences[i])
             np_test.assert_almost_equal(
-                inf.query(["parent"], evidence).normalize(inplace=False).values,
+                inf.query(["parent"], evidence, show_progress=False)
+                .normalize(inplace=False)
+                .values,
                 expected_values[i],
                 decimal=2,
             )
