@@ -3,14 +3,14 @@ from unittest import TestCase
 import numpy as np
 import pandas as pd
 
-from pgmpy.models import BayesianNetwork
 from pgmpy.inference.EliminationOrder import (
     BaseEliminationOrder,
-    WeightedMinFill,
+    MinFill,
     MinNeighbors,
     MinWeight,
-    MinFill,
+    WeightedMinFill,
 )
+from pgmpy.models import BayesianNetwork
 
 
 class BaseEliminationTest(TestCase):
@@ -52,13 +52,15 @@ class TestWeightedMinFill(BaseEliminationTest):
             self.assertEqual(self.elimination_order.cost(var), expected_cost)
 
     def test_elimination_order(self):
-        elimination_order = self.elimination_order.get_elimination_order()
+        elimination_order = self.elimination_order.get_elimination_order(
+            show_progress=False
+        )
         self.assertEqual(set(elimination_order[:2]), {"sat", "reco"})
         self.assertEqual(set(elimination_order[2:]), {"grade", "intel", "diff"})
 
     def test_elimination_order_given_nodes(self):
         elimination_order = self.elimination_order.get_elimination_order(
-            nodes=["diff", "grade", "sat"]
+            nodes=["diff", "grade", "sat"], show_progress=False
         )
         self.assertEqual(elimination_order, ["sat", "diff", "grade"])
 
@@ -74,13 +76,15 @@ class TestMinNeighbors(BaseEliminationTest):
         self.assertEqual(self.elimination_order.cost("intel"), 3)
 
     def test_elimination_order(self):
-        elimination_order = self.elimination_order.get_elimination_order()
+        elimination_order = self.elimination_order.get_elimination_order(
+            show_progress=False
+        )
         self.assertEqual(set(elimination_order[:2]), {"sat", "reco"})
         self.assertEqual(set(elimination_order[2:]), {"diff", "grade", "intel"})
 
     def test_elimination_order_given_nodes(self):
         elimination_order = self.elimination_order.get_elimination_order(
-            nodes=["diff", "grade", "sat"]
+            nodes=["diff", "grade", "sat"], show_progress=False
         )
         self.assertEqual(elimination_order, ["sat", "diff", "grade"])
 
@@ -96,14 +100,16 @@ class TestMinWeight(BaseEliminationTest):
         self.assertEqual(self.elimination_order.cost("reco"), 2)
 
     def test_elimination_order(self):
-        elimination_order = self.elimination_order.get_elimination_order()
+        elimination_order = self.elimination_order.get_elimination_order(
+            show_progress=False
+        )
         self.assertTrue(elimination_order[0] in ["sat", "reco"])
         self.assertTrue(elimination_order[1] in ["sat", "reco"])
         self.assertEqual(set(elimination_order[2:]), {"diff", "intel", "grade"})
 
     def test_elimination_order_given_nodes(self):
         elimination_order = self.elimination_order.get_elimination_order(
-            nodes=["diff", "grade", "sat"]
+            nodes=["diff", "grade", "sat"], show_progress=False
         )
         self.assertEqual(elimination_order, ["sat", "diff", "grade"])
 
@@ -119,13 +125,15 @@ class TestMinFill(BaseEliminationTest):
         self.assertEqual(self.elimination_order.cost("sat"), 0)
 
     def test_elimination_order(self):
-        elimination_order = self.elimination_order.get_elimination_order()
+        elimination_order = self.elimination_order.get_elimination_order(
+            show_progress=False
+        )
         self.assertEqual(
             set(elimination_order), {"diff", "grade", "sat", "reco", "intel"}
         )
 
     def test_elimination_order_given_nodes(self):
         elimination_order = self.elimination_order.get_elimination_order(
-            nodes=["diff", "grade", "intel"]
+            nodes=["diff", "grade", "intel"], show_progress=False
         )
         self.assertEqual(set(elimination_order), {"diff", "grade", "intel"})
