@@ -1,27 +1,26 @@
 import unittest
 
 import networkx as nx
-import pandas as pd
 import numpy as np
 import numpy.testing as np_test
+import pandas as pd
 
-from pgmpy.models import BayesianModel, MarkovModel
-from pgmpy.base import DAG
 import pgmpy.tests.help_functions as hf
-from pgmpy.factors.discrete import (
-    TabularCPD,
-    JointProbabilityDistribution,
-    DiscreteFactor,
-)
-from pgmpy.independencies import Independencies
+from pgmpy.base import DAG
 from pgmpy.estimators import (
-    BayesianEstimator,
     BaseEstimator,
+    BayesianEstimator,
     MaximumLikelihoodEstimator,
 )
-from pgmpy.base import DAG
-from pgmpy.utils import get_example_model
+from pgmpy.factors.discrete import (
+    DiscreteFactor,
+    JointProbabilityDistribution,
+    TabularCPD,
+)
+from pgmpy.independencies import Independencies
+from pgmpy.models import BayesianModel, MarkovModel
 from pgmpy.sampling import BayesianModelSampling
+from pgmpy.utils import get_example_model
 
 
 class TestBaseModelCreation(unittest.TestCase):
@@ -175,12 +174,12 @@ class TestBayesianModelMethods(unittest.TestCase):
             )
 
     def test_get_ancestors_of_success(self):
-        ancenstors1 = self.G2._get_ancestors_of("g")
-        ancenstors2 = self.G2._get_ancestors_of("d")
-        ancenstors3 = self.G2._get_ancestors_of(["i", "l"])
-        self.assertEqual(ancenstors1, {"d", "i", "g"})
-        self.assertEqual(ancenstors2, {"d"})
-        self.assertEqual(ancenstors3, {"g", "i", "l", "d"})
+        ancestors1 = self.G2._get_ancestors_of("g")
+        ancestors2 = self.G2._get_ancestors_of("d")
+        ancestors3 = self.G2._get_ancestors_of(["i", "l"])
+        self.assertEqual(ancestors1, {"d", "i", "g"})
+        self.assertEqual(ancestors2, {"d"})
+        self.assertEqual(ancestors3, {"g", "i", "l", "d"})
 
     def test_get_ancestors_of_failure(self):
         self.assertRaises(ValueError, self.G2._get_ancestors_of, "h")
@@ -263,7 +262,7 @@ class TestBayesianModelMethods(unittest.TestCase):
         self.assertTrue(self.G1.is_imap(JPD))
         self.assertRaises(TypeError, self.G1.is_imap, fac)
 
-    def test_markov_blanet(self):
+    def test_markov_blanket(self):
         G = DAG(
             [
                 ("x", "y"),
@@ -1192,7 +1191,7 @@ class TestBayesianModelFitPredict(unittest.TestCase):
         )
 
     def test_do(self):
-        # One confounder var with treatement T and outcome C: S -> T -> C ; S -> C
+        # One confounder var with treatment T and outcome C: S -> T -> C ; S -> C
         model = BayesianModel([("S", "T"), ("T", "C"), ("S", "C")])
         cpd_s = TabularCPD(
             variable="S",
@@ -1238,7 +1237,7 @@ class TestBayesianModelFitPredict(unittest.TestCase):
     def test_simulate(self):
         asia = get_example_model("asia")
         n_samples = int(1e3)
-        samples = asia.simulate(n_samples=n_samples)
+        samples = asia.simulate(n_samples=n_samples, show_progress=False)
         self.assertEqual(samples.shape[0], n_samples)
 
     def tearDown(self):
