@@ -2,27 +2,26 @@ import os
 import unittest
 
 import networkx as nx
-import pandas as pd
 import numpy as np
 import numpy.testing as np_test
+import pandas as pd
 
-from pgmpy.models import BayesianNetwork, MarkovNetwork
-from pgmpy.base import DAG
 import pgmpy.tests.help_functions as hf
-from pgmpy.factors.discrete import (
-    TabularCPD,
-    JointProbabilityDistribution,
-    DiscreteFactor,
-)
-from pgmpy.independencies import Independencies
+from pgmpy.base import DAG
 from pgmpy.estimators import (
-    BayesianEstimator,
     BaseEstimator,
+    BayesianEstimator,
     MaximumLikelihoodEstimator,
 )
-from pgmpy.base import DAG
-from pgmpy.utils import get_example_model
+from pgmpy.factors.discrete import (
+    DiscreteFactor,
+    JointProbabilityDistribution,
+    TabularCPD,
+)
+from pgmpy.independencies import Independencies
+from pgmpy.models import BayesianNetwork, MarkovNetwork
 from pgmpy.sampling import BayesianModelSampling
+from pgmpy.utils import get_example_model
 
 
 class TestBaseModelCreation(unittest.TestCase):
@@ -178,12 +177,12 @@ class TestBayesianModelMethods(unittest.TestCase):
             )
 
     def test_get_ancestors_of_success(self):
-        ancenstors1 = self.G2._get_ancestors_of("g")
-        ancenstors2 = self.G2._get_ancestors_of("d")
-        ancenstors3 = self.G2._get_ancestors_of(["i", "l"])
-        self.assertEqual(ancenstors1, {"d", "i", "g"})
-        self.assertEqual(ancenstors2, {"d"})
-        self.assertEqual(ancenstors3, {"g", "i", "l", "d"})
+        ancestors1 = self.G2._get_ancestors_of("g")
+        ancestors2 = self.G2._get_ancestors_of("d")
+        ancestors3 = self.G2._get_ancestors_of(["i", "l"])
+        self.assertEqual(ancestors1, {"d", "i", "g"})
+        self.assertEqual(ancestors2, {"d"})
+        self.assertEqual(ancestors3, {"g", "i", "l", "d"})
 
     def test_get_ancestors_of_failure(self):
         self.assertRaises(ValueError, self.G2._get_ancestors_of, "h")
@@ -271,7 +270,7 @@ class TestBayesianModelMethods(unittest.TestCase):
         self.assertTrue(self.G1.is_imap(JPD))
         self.assertRaises(TypeError, self.G1.is_imap, fac)
 
-    def test_markov_blanet(self):
+    def test_markov_blanket(self):
         G = DAG(
             [
                 ("x", "y"),
@@ -365,6 +364,31 @@ class TestBayesianModelMethods(unittest.TestCase):
         for cpd in model.cpds:
             self.assertTrue(np.allclose(np.sum(cpd.get_values(), axis=0), 1, atol=0.01))
 
+    def test_get_random_cpds(self):
+        model = BayesianNetwork(DAG.get_random(n_nodes=5, edge_prob=0.5).edges())
+
+        param_model = model.get_random_cpds()
+        self.assertEqual(len(param_model.cpds), 5)
+        self.assertTrue(param_model.check_model())
+
+        param_model = model.get_random_cpds(n_states=4)
+        self.assertEqual(len(param_model.cpds), 5)
+        self.assertTrue(param_model.check_model())
+        self.assertTrue(
+            all([card == 4 for var, card in param_model.get_cardinality().items()])
+        )
+
+        n_states_dict = {0: 3, 1: 5, 2: 4, 3: 9, 4: 3}
+        param_model = model.get_random_cpds(n_states=n_states_dict)
+        self.assertEqual(len(param_model.cpds), 5)
+        self.assertTrue(param_model.check_model())
+        for var in range(5):
+            self.assertEqual(param_model.get_cardinality(var), n_states_dict[var])
+
+        model.get_random_cpds(inplace=True)
+        self.assertEqual(len(model.cpds), 5)
+        self.assertTrue(model.check_model())
+
     def test_remove_node(self):
         self.G1.remove_node("diff")
         self.assertEqual(sorted(self.G1.nodes()), sorted(["grade", "intel"]))
@@ -377,7 +401,7 @@ class TestBayesianModelMethods(unittest.TestCase):
         self.assertRaises(ValueError, self.G1.get_cpds, "grade")
 
     def test_do(self):
-        # One confounder var with treatement T and outcome C: S -> T -> C ; S -> C
+        # One confounder var with treatment T and outcome C: S -> T -> C ; S -> C
         model = BayesianNetwork([("S", "T"), ("T", "C"), ("S", "C")])
         cpd_s = TabularCPD(
             variable="S",
@@ -423,12 +447,12 @@ class TestBayesianModelMethods(unittest.TestCase):
     def test_simulate(self):
         asia = get_example_model("asia")
         n_samples = int(1e3)
-        samples = asia.simulate(n_samples=n_samples)
+        samples = asia.simulate(n_samples=n_samples, show_progress=False)
         self.assertEqual(samples.shape[0], n_samples)
 
         # The probability values don't sum to 1 in this case.
         barley = get_example_model("barley")
-        samples = barley.simulate(n_samples=n_samples)
+        samples = barley.simulate(n_samples=n_samples, show_progress=False)
         self.assertEqual(samples.shape[0], n_samples)
 
     def test_load_save(self):
@@ -1457,8 +1481,7 @@ class TestDAGCPDOperations(unittest.TestCase):
 
 class TestSimulation(unittest.TestCase):
     def setUp(self):
-        from pgmpy.inference import VariableElimination
-        from pgmpy.inference import CausalInference
+        from pgmpy.inference import CausalInference, VariableElimination
 
         self.alarm = get_example_model("alarm")
         self.infer_alarm = VariableElimination(self.alarm)
@@ -1512,20 +1535,24 @@ class TestSimulation(unittest.TestCase):
                 )
 
     def test_simulate(self):
-        con_model_samples = self.con_model.simulate(n_samples=int(1e4))
+        con_model_samples = self.con_model.simulate(
+            n_samples=int(1e4), show_progress=False
+        )
         con_inference_marginals = self.infer_con_model.query(
             self.con_model.nodes(), joint=False
         )
         self._test_con_marginals_equal(con_model_samples, con_inference_marginals)
 
         nodes = list(self.alarm.nodes())[:5]
-        alarm_samples = self.alarm.simulate(n_samples=int(1e4))
+        alarm_samples = self.alarm.simulate(n_samples=int(1e4), show_progress=False)
         alarm_inference_marginals = self.infer_alarm.query(list(nodes), joint=False)
         self._test_alarm_marginals_equal(alarm_samples, alarm_inference_marginals)
 
     def test_simulate_evidence(self):
         con_model_samples = self.con_model.simulate(
-            n_samples=int(1e4), evidence={"U": 1}
+            n_samples=int(1e4),
+            evidence={"U": 1},
+            show_progress=False,
         )
         con_inference_marginals = self.infer_con_model.query(
             ["X", "Y", "Z"], joint=False, evidence={"U": 1}
@@ -1534,25 +1561,38 @@ class TestSimulation(unittest.TestCase):
 
         nodes = list(self.alarm.nodes())[:5]
         alarm_samples = self.alarm.simulate(
-            n_samples=int(1e4), evidence={"MINVOLSET": "HIGH"}
+            n_samples=int(1e4), evidence={"MINVOLSET": "HIGH"}, show_progress=False
         )
         alarm_inference_marginals = self.infer_alarm.query(list(nodes), joint=False)
         self._test_alarm_marginals_equal(alarm_samples, alarm_inference_marginals)
 
+        self.assertRaises(
+            ValueError,
+            self.alarm.simulate,
+            n_samples=int(1e4),
+            evidence={"MINVOLSET": "UNKNOWN"},
+        )
+
     def test_simulate_intervention(self):
-        con_model_samples = self.con_model.simulate(n_samples=int(1e4), do={"X": 1})
+        con_model_samples = self.con_model.simulate(
+            n_samples=int(1e4), do={"X": 1}, show_progress=False
+        )
         con_inference_marginals = {
             "Y": self.causal_infer_con_model.query(["Y"], do={"X": 1})
         }
         self._test_con_marginals_equal(con_model_samples, con_inference_marginals)
 
-        con_model_samples = self.con_model.simulate(n_samples=int(1e4), do={"Z": 1})
+        con_model_samples = self.con_model.simulate(
+            n_samples=int(1e4), do={"Z": 1}, show_progress=False
+        )
         con_inference_marginals = {
             "X": self.causal_infer_con_model.query(["X"], do={"Z": 1})
         }
         self._test_con_marginals_equal(con_model_samples, con_inference_marginals)
 
-        alarm_samples = self.alarm.simulate(n_samples=int(1e4), do={"CVP": "LOW"})
+        alarm_samples = self.alarm.simulate(
+            n_samples=int(1e4), do={"CVP": "LOW"}, show_progress=False
+        )
         alarm_inference_marginals = {
             "HISTORY": self.causal_infer_alarm.query(["HISTORY"], do={"CVP": "LOW"}),
             "HR": self.causal_infer_alarm.query(["HR"], do={"CVP": "LOW"}),
@@ -1563,7 +1603,7 @@ class TestSimulation(unittest.TestCase):
         self._test_alarm_marginals_equal(alarm_samples, alarm_inference_marginals)
 
         alarm_samples = self.alarm.simulate(
-            n_samples=int(1e4), do={"MINVOLSET": "NORMAL"}
+            n_samples=int(1e4), do={"MINVOLSET": "NORMAL"}, show_progress=False
         )
         alarm_inference_marginals = {
             "CVP": self.causal_infer_alarm.query(["CVP"], do={"MINVOLSET": "NORMAL"}),
@@ -1577,13 +1617,20 @@ class TestSimulation(unittest.TestCase):
         }
         self._test_alarm_marginals_equal(alarm_samples, alarm_inference_marginals)
 
+        self.assertRaises(
+            ValueError,
+            self.alarm.simulate,
+            n_samples=int(1e4),
+            do={"MINVOLSET": "UNKNOWN"},
+        )
+
     def test_simulate_virtual_evidence(self):
         # Use virtual evidence argument to simulate hard evidence and match values from inference.
 
         # Simulates hard evidence U = 1
         virtual_evidence = TabularCPD("U", 2, [[0.0], [1.0]])
         con_model_samples = self.con_model.simulate(
-            n_samples=int(1e4), virtual_evidence=[virtual_evidence]
+            n_samples=int(1e4), virtual_evidence=[virtual_evidence], show_progress=False
         )
         con_inference_marginals = self.infer_con_model.query(
             ["X", "Y", "Z"], joint=False, evidence={"U": 1}
@@ -1599,7 +1646,7 @@ class TestSimulation(unittest.TestCase):
             state_names={"MINVOLSET": ["LOW", "NORMAL", "HIGH"]},
         )
         alarm_samples = self.alarm.simulate(
-            n_samples=int(1e4), virtual_evidence=[virtual_evidence]
+            n_samples=int(1e4), virtual_evidence=[virtual_evidence], show_progress=False
         )
         alarm_inference_marginals = self.infer_alarm.query(list(nodes), joint=False)
         self._test_alarm_marginals_equal(alarm_samples, alarm_inference_marginals)
@@ -1610,7 +1657,7 @@ class TestSimulation(unittest.TestCase):
         # Simulate hard intervention X=1
         virt_inter = TabularCPD("X", 2, [[0.0], [1.0]])
         con_model_samples = self.con_model.simulate(
-            n_samples=int(1e4), virtual_intervention=[virt_inter]
+            n_samples=int(1e4), virtual_intervention=[virt_inter], show_progress=False
         )
         con_inference_marginals = {
             "Y": self.causal_infer_con_model.query(["Y"], do={"X": 1}),
@@ -1620,7 +1667,7 @@ class TestSimulation(unittest.TestCase):
         # Simulate hard intervention Z=1
         virt_inter = TabularCPD("Z", 2, [[0.0], [1.0]])
         con_model_samples = self.con_model.simulate(
-            n_samples=int(1e4), virtual_intervention=[virt_inter]
+            n_samples=int(1e4), virtual_intervention=[virt_inter], show_progress=False
         )
         con_inference_marginals = {
             "X": self.causal_infer_con_model.query(["X"], do={"Z": 1})
@@ -1635,7 +1682,7 @@ class TestSimulation(unittest.TestCase):
             state_names={"CVP": ["LOW", "NORMAL", "HIGH"]},
         )
         alarm_samples = self.alarm.simulate(
-            n_samples=int(1e4), virtual_intervention=[virt_inter]
+            n_samples=int(1e4), virtual_intervention=[virt_inter], show_progress=False
         )
         alarm_inference_marginals = {
             "HISTORY": self.causal_infer_alarm.query(["HISTORY"], do={"CVP": "LOW"}),
@@ -1654,7 +1701,7 @@ class TestSimulation(unittest.TestCase):
             state_names={"MINVOLSET": ["LOW", "NORMAL", "HIGH"]},
         )
         alarm_samples = self.alarm.simulate(
-            n_samples=int(1e4), virtual_intervention=[virt_inter]
+            n_samples=int(1e4), virtual_intervention=[virt_inter], show_progress=False
         )
         alarm_inference_marginals = {
             "CVP": self.causal_infer_alarm.query(["CVP"], do={"MINVOLSET": "NORMAL"}),
