@@ -2,6 +2,7 @@ from .mathext import cartesian, sample_discrete
 from .state_name import StateNameMixin
 from .check_functions import _check_1d_array_object, _check_length_equal
 from .optimizer import optimize, pinverse
+from .utils import get_example_model
 
 
 __all__ = [
@@ -12,4 +13,5 @@ __all__ = [
     "_check_length_equal",
     "optimize",
     "pinverse",
+    "get_example_model",
 ]
